#
#
# $Id$
#
# This program is free software; you can redistribute it and/or 
# modify it under the terms of the GNU General Public License, version 2.
#
# Infobrowser support for the BBC Whats On  items
#
package Plugins::InfoBrowserAddons::RecentlyPlayedSkyFM::RecentlyPlayedSkyFMParser;

# Parser for www.sky.fm's recently played pages

use strict;

use Slim::Utils::Log;

use HTML::PullParser;
use HTML::Entities;
use Date::Parse qw(str2time);

my $log = logger('plugin.infobrowser');


sub getDisplayName { 'Recently Played SkyFM ' };

sub getnexttag
{
  my $t;
  my $p         = shift;
  my $searchtag = shift;
  my $exittag   = shift ;

  for (;;) {
     $t = $p->get_token();
     return undef unless (defined($t));
     return $t if ( $t->[1] eq $searchtag) ;
     return $t if ( defined ($exittag) && $t->[1] eq $exittag) ;
  }
}


sub cleanup
{
  my $str = shift;
  return undef unless defined ($str); 
  
  $str =~ s/\n/ /g;  # change LF to space
  $str =~ s/\r//g;   # Get rid of CR if any.
  $str =~ s/<br>//g; # Get rid of HTML <br> if any.
  $str =~ s/<br \/>//g; # Get rid of HTML <br> if any.
  $str =~ s/<BR>//g; # Get rid of HTML <BR> if any.
  $str =~ s/<B>//g; # Get rid of HTML <B> if any.
  $str =~ s/<\/B>//g; # Get rid of HTML </B> if any.
  $str =~ s/&nbsp;/ /g; # replace HTML &nbsp if any.

# strip whitespace from beginning and end

  $str =~ s/^\s*//; 
  $str =~ s/\s*$//; 
  

  return $str;
}


sub parse
{

	my $class  = shift;
	my $http   = shift;

	my $params = $http->params('params');
	my $url    = $params->{'url'};
	my $title  = $params->{'text'};
	my @list;
	my $token;

	my $p = HTML::PullParser->new(api_version => 3, doc => ${$http->contentRef},
		      	    	  start => 'event, tag, attr,  skipped_text',
			    	  end   => 'event, tag, dtext, skipped_text',
			          report_tags => [qw ( div)]);

	# get first table with Titles
	while ($token = getnexttag($p,"div")) {
		next unless ( defined ($token->[2]->{class} )) ;
		next if ( $token->[2]->{class} ne 'text_trackname');

		$token = getnexttag($p,"/div");
	        my $trackname = cleanup($token->[3]);

	        $log->debug( "Trackname is $trackname");

		         push @list,{	'name'   =>  "$trackname"};

	}		

return {
		'type'  => 'opml',
		'name' => "RecentlyPlayedSkyFM - parsed",
		'description' => "Recently played on $title ",
		'items' => [ @list],
	};

}

# Local Variables:
# tab-width:4
# indent-tabs-mode:t
# End:

1;
